@@ -12,7 +12,7 @@ case "$version" in
 		echo "You need revision 1.0.7 or 1.2.1" 1>&2
 		exit 1
 		;;	
-	1.2.[0-9])
+	1.2.[0-9]|1.[3-9]*|1.1[0-9]*)
 		# OK
 		echo 1>/dev/null
 		;;
@@ -22,7 +22,7 @@ case "$version" in
 		;;
 	*)
 		echo "GNU Privacy Guard revision 1.0.7 or 1.2.x is required." 1>&2
-		echo "You have tar [$version]." 1>&2
+		echo "You have gpg [$version]." 1>&2
 		echo "This test has not been run." 1>&2
 		exit 1
 		;;
