@@ -508,7 +508,7 @@ main(int argc, char **argv)
 	pid_t target_write_pid = 0;
 	pid_t target_pump_pid = 0;
 	int is_target_local_regular_file = 0;
-	char * optionname;
+	char * optionname = NULL;
 	SWI_DISTDATA * distdataO;
 
 	char * opt_option_files = (char*)NULL;
@@ -2249,7 +2249,7 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 			ret = 0;
 			if (f_retval == 0)
 				ret = swpl_send_success(swicol, target_fdar[1], G->g_swi_event_fd,
-						SWBIS_TS_Do_nothing ": testing 123");
+						SWBIS_TS_Do_nothing ": guarding 123");
 			if (ret != 0) {
 				abort_script(swicol, G, target_fdar[1]);
         			swpl_send_abort(swicol, target_fdar[1], G->g_swi_event_fd, "");
@@ -2275,6 +2275,10 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 				response_img = NULL;
 			}
 
+			if (f_retval == 0)
+				swpl_send_success(swicol, target_fdar[1], G->g_swi_event_fd,
+					SWBIS_TS_Do_nothing ": guarding 1234");
+
 			E_DEBUG("");
 
 			/* Now parse the response */
@@ -2385,7 +2389,7 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 					if (ret < 0) {
 						/* error that is incompatible with continuing */
 						E_DEBUG("");
-						raise(SIGINT);
+						/* raise(SIGINT); */
 						f_retval++;
 						break;
 					}
@@ -2429,9 +2433,10 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 			swc_check_for_current_signals(G, __LINE__, wopt_no_remote_kill);
 
 			ret = 0;
-			if (f_retval == 0)
+			if (1 || f_retval == 0) {
 				ret = swpl_send_success(swicol, target_fdar[1], G->g_swi_event_fd,
-						SWBIS_TS_Do_nothing ": testing 89");
+						SWBIS_TS_Do_nothing ": guarding 89");
+			}
 
 			if (ret != 0) {
 				abort_script(swicol, G, target_fdar[1]);
