@@ -51,6 +51,7 @@
 #include "swproglib.h"
 #include "swconfig_lib.h"
 #include "atomicio.h"
+#include "swlex_supp.h"
 
 #define SWCONFIG_UPVERBOSE	0
 #define PROGNAME                SW_UTN_CONFIG
@@ -526,6 +527,8 @@ main(int argc, char **argv)
 	int local_stdout_in_use = 0;
 	int reqs_failed = 0;
 	int rp_status;
+	int did_skip;
+	int total_skipped = 0;
 	struct extendedOptions * opta = optionsArray;
 	struct termios	*login_orig_termiosP = NULL;
 	struct winsize	*login_sizeP = NULL;
@@ -1526,6 +1529,9 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 						G->g_targetfd_array, 
 						"/", /* XX FIXME */
 						&num_remains);
+
+	swlex_set_input_policy(SWLEX_INPUT_UTF_TR);
+
 	/*
 	 * = = = = = = = = = = = = = = = = = = = = = = = = = = = 
 	 *           Loop over the targets.
@@ -1548,6 +1554,7 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 		swgp_signal(SIGTERM, safe_sig_handler);
 		swgp_signal(SIGUSR1, safe_sig_handler);
 		*/
+		total_skipped = 0;
 		statbytes = 0;
 		found_ambig = 0;
 		s_retval = 0;
@@ -2124,7 +2131,7 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 			ret = 0;
 			if (f_retval == 0)
 				ret = swpl_send_success(swicol, target_fdar[1], G->g_swi_event_fd,
-						SWBIS_TS_Do_nothing ": testing 123");
+						SWBIS_TS_Do_nothing ": guarding 123");
 			if (ret != 0) {
 				abort_script(swicol, G, target_fdar[1]);
         			swpl_send_abort(swicol, target_fdar[1], G->g_swi_event_fd, "");
@@ -2150,6 +2157,10 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 			}
 
 			E_DEBUG("");
+			
+			if (f_retval == 0)
+				 swpl_send_success(swicol, target_fdar[1], G->g_swi_event_fd,
+						SWBIS_TS_Do_nothing ": guarding 1234");
 
 			/* Now parse the response */
 			sl = NULL;		
@@ -2235,12 +2246,15 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 					E_DEBUG2("SWEVERID: %s", swverid_show_object_debug(sr->swspecM, NULL, "sr->swspecM:"));
 					E_DEBUG2("SWEVERID LOCATION: %s", swverid_get_verid_value(sr->swspecM, SWVERID_VERIDS_LOCATION, 1));
 
+					did_skip = 0;
 					ret = swconfig_looper_sr_payload(G, target_path, swicol,
 								sr,
 								target_fdar[1],
 								target_fdar[0],
 								&rp_status,
-								uts);
+								uts, &did_skip);
+
+					if (did_skip) total_skipped++;
 
 					/* rp_status is the script return status
 					   ret, if non-zero is a protocol or internal error */
@@ -2258,7 +2272,7 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 					E_DEBUG2("signal_flag=%d", G->g_signal_flag);
 					if (ret < 0) {
 						/* error that is incompatible with continuing */
-						raise(SIGINT);
+						/* raise(SIGINT); */
 						f_retval++;
 						break;
 					}
@@ -2296,10 +2310,12 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 
 			E_DEBUG("");
 			ret = 0;
-			if (f_retval == 0)
+			if (1 || f_retval == 0) {
+				/* this need to be executed even if the looper exited with error */
 				ret = swpl_send_success(swicol, target_fdar[1], G->g_swi_event_fd,
-						SWBIS_TS_Do_nothing ": testing 89");
+						SWBIS_TS_Do_nothing ": guarding 89");
 
+			}
 			E_DEBUG("");
 			if (ret != 0) {
 				abort_script(swicol, G, target_fdar[1]);
@@ -2405,11 +2421,17 @@ ENTER_WITH_FAILURE2:
 				G->g_verboseG);
 		}
 		E_DEBUG("");
-		swlib_wait_on_all_pids(
+		swlib_wait_on_all_pids_with_timeout(
+				G->g_pid_array, 
+				G->g_pid_array_len, 
+				G->g_status_array, WNOHANG /*waitpid flags*/, 
+				G->g_verboseG - 2, -3 /* after 3 seconds, kill*/);
+		
+		swlib_wait_on_all_pids_with_timeout(
 				G->g_pid_array, 
 				G->g_pid_array_len, 
 				G->g_status_array, 0 /*waitpid flags*/, 
-				G->g_verboseG - 2);
+				G->g_verboseG - 2, 0);
 
 		E_DEBUG("");
 
@@ -2457,7 +2479,7 @@ TARGET1:
 		target_script_pid = NULL;
 
 		target_loop_count++;
-		if (f_retval == 0) target_success_count++;
+		if (f_retval == 0 && total_skipped == 0) target_success_count++;
 		swlib_doif_writef(G->g_verboseG, SWC_VERBOSE_2 + SWCONFIG_UPVERBOSE,
 				&G->g_logspec, f_retval ? swc_get_stderr_fd(G) : swevent_fd,
 			"SWBIS_TARGET_ENDS for %s: status=%d\n",
