@@ -384,7 +384,7 @@ looper_locked_region(STROB * buf, int vlv)
 
 		"				shls_bashin2 \"" SWBIS_TS_make_live_INSTALLED  "\"\n"
 		"				sw_retval=$?\n"
-		"				case $sw_retval in 0) $sh_dash_s " SWBIS_TS_make_live_INSTALLED ";; *) shls_false_;; esac\n"
+		"				case $sw_retval in 0) $sh_dash_s " SWBIS_TS_make_live_INSTALLED ";; *) sleep 2; shls_false_;; esac\n"
 		"				sw_retval=$?\n"
 		"				swexec_status=$sw_retval\n"
 
@@ -500,7 +500,13 @@ merge_cisf_process_product(CISF_PRODUCT * cisf_product, SWHEADER * swheader)
 			create_time = swheader_get_single_attribute_value(swheader, SW_A_create_time);
 			mod_time = swheader_get_single_attribute_value(swheader, SW_A_mod_time);
 			state = swheader_get_single_attribute_value(swheader, SW_A_state);
-			strncpy(fileset->stateM, state, sizeof(fileset->stateM) -1);
+			if (state) {
+				E_DEBUG("");
+				strncpy(fileset->stateM, state, sizeof(fileset->stateM) -1);
+			} else {
+				E_DEBUG("state attribute not found");
+
+			}
 			fileset->stateM[sizeof(fileset->stateM)-1] = '\0';
 			merge_cisf_update_times(create_time, mod_time, &(cisf_fileset->cisf_baseM.ixfileM->baseM));
 		} else if (strcmp(object_keyword, SW_A_control_file) == 0) {
@@ -988,6 +994,12 @@ swconfig_write_source_copy_script2(GB * G,
 		"case $sw_retval in 0) $sh_dash_s " SWBIS_TS_Get_iscs_listing ";; *) shls_false_;; esac\n"
 		"sw_retval=$?\n"
 		"swexec_status=$sw_retval\n"
+		
+		"shls_bashin2 \"" SWBIS_TS_Do_nothing "\"\n"
+		"sw_retval=$?\n"
+		"case $sw_retval in 0) $sh_dash_s " SWBIS_TS_Do_nothing ";; *) shls_false_;; esac\n"
+		"sw_retval=$?\n"
+		"swexec_status=$sw_retval\n"
 
 		/* Loop over the selections */
 		"		shls_looper \"$sw_retval\"\n"
@@ -1104,7 +1116,7 @@ swconfig_write_source_copy_script2(GB * G,
 
 int
 swconfig_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
-		SWICAT_SR * sr, int ofd, int ifd, int * p_rp_status, SWUTS * uts)
+		SWICAT_SR * sr, int ofd, int ifd, int * p_rp_status, SWUTS * uts, int * did_skip)
 {
 	int retval;
 	int rstatus;
@@ -1255,10 +1267,11 @@ swconfig_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 
 	e = swicat_e_create();
 	ret = swicat_e_open_entry_tarball(e, ifd);
-	if (ret < 0) {
+	E_DEBUG("");
+	if (ret != 0) {
 		sw_e_msg(G, "error opening catalog entry tarball, ret=%d\n", ret);
 		rstatus = 1;
-		retval = -1;  /* protocol internal error */
+		retval = -2;  /* protocol internal error */
 		looper_abort(G, swicol, ofd);
 		goto error_out;
 	} else if (ret == SWICAT_RETVAL_NULLARCHIVE) {
@@ -1269,6 +1282,7 @@ swconfig_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 	} else {
 		; /* Normal path */
 	}
+	E_DEBUG("");
 
 	/* e->entry_prefixM has the installed_software_catalog
 	  path already prefixed */
@@ -1276,32 +1290,38 @@ swconfig_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 	if (G->devel_verboseM)
 		SWLIB_INFO2("catalog entry (active) path = %s", epath);
 	
+	E_DEBUG("");
 	epath = swicat_e_form_catalog_path(e, btmp, NULL, SWICAT_DEACTIVE_ENTRY);
 	if (G->devel_verboseM)
 		SWLIB_INFO2("catalog entry path (inactive) path = %s", epath);
 
+	E_DEBUG("");
 	epath = swicat_e_form_catalog_path(e, btmp, NULL, SWICAT_ACTIVE_ENTRY);
 
 	/* epath is now a clean relative path to such as:
 		var/lib/swbis/catalog/emacs/emacs/21.2.1/0  */
 
+	E_DEBUG("");
 	ret = swicat_e_reset_fd(e);
 	if (ret < 0) {
 		rstatus = 2;
-		retval = -1;
+		retval = -3;
 		sw_e_msg(G, "error reseting swicat_e object, ret=%d\n", ret);
 		looper_abort(G, swicol, ofd);
 		goto error_out;
 	}
 
+	E_DEBUG("");
 	/* Now obtain the verification status for each signature */
 	if (G->devel_verboseM)
 		SWLIB_INFO2("NOPEN=%d", uxfio_uxfio_get_nopen());
 
+	E_DEBUG("");
 	swgpg = swgpg_create();
 	if (G->devel_verboseM)
 		SWLIB_INFO2("NOPEN=%d", uxfio_uxfio_get_nopen());
 
+	E_DEBUG("");
 	ret = 0;
 	if (sig_level >= 0)
 		ret = swicat_e_verify_gpg_signature(e, swgpg);
@@ -1314,14 +1334,16 @@ swconfig_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 	/* Now interpret the verification results according to extended option
 	   requirements */
 
+	E_DEBUG("");
 	ret = 0;
 	if (sig_level >= 0)
 		ret = swpl_signature_policy_accept(G, swgpg, G->g_verboseG, strob_str(swspec_string));
+	E_DEBUG("");
 	if (ret != 0) {
 		/* Bad signature or not enough good signatures
 		   Can't use the blob to make a removal file list
 		   because were assuming its tainted. */
-		rstatus = 4;
+		rstatus = SWP_RP_STATUS_NO_INTEGRITY;
 		retval = 0;
 		do_skip_entry = 1;
 	} else {
@@ -1334,15 +1356,14 @@ swconfig_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 	 * because its authenticated or we don't care.
 	 */
 
+	E_DEBUG("");
 	swi = swicat_e_open_swi(e);
 	if (swi == NULL) {
 		/* swi might be NULL due to file system permission,
 		   handle NULL gracefully */
 		do_skip_entry = 1;
-		sw_e_msg(G, "catalog read error, possible permission denied: %s/%s\n", target_path, epath);
-	}
-	
-	if (swi) {
+		sw_e_msg(G, "catalog read error: %s/%s\n", target_path, epath);
+	} else {
 		swi->swi_pkgM->catalog_entryM = strdup(epath); /* FIXME, this must set explicitly */
 		swi->swi_pkgM->target_pathM = strdup(target_path); /* FIXME, this must set explicitly */
 		swi->swi_pkgM->installed_software_catalogM = strdup(get_opta_isc(G->optaM, SW_E_installed_software_catalog));
@@ -1354,12 +1375,12 @@ swconfig_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 		}
 	}
 
+	E_DEBUG("");
 	/* Now map the sections of the INSTALLED file to
 	   the (SWI*) object, this is done by 
 	   swpl_cisf_<*> routines and stored in the
 	   (CISF_PRODUCT*) object. */
 
-
 	if (G->devel_verboseM)
 		SWLIB_INFO2("NOPEN=%d", uxfio_uxfio_get_nopen());
 	if (swi) swi->optaM = G->optaM;
@@ -1377,10 +1398,10 @@ swconfig_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 	*p_rp_status = ret;
 	E_DEBUG2("rp_status is %d", ret);
 	if (ret) {
-		/* looper_abort(G, swicol, ofd); */
 		rstatus = 6;
-		retval = 0;
+		retval = -4;
 		do_skip_entry = 1;
+		goto error_out;
 	}
 	if (G->g_do_debug_events)
 		swicol_show_events_to_fd(swicol, STDERR_FILENO, -1);
@@ -1391,36 +1412,46 @@ swconfig_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 	*p_rp_status = ret;
 	E_DEBUG2("rp_status is %d", ret);
 	if (ret) {
-		looper_abort(G, swicol, ofd);
+		E_DEBUG("error");
+		rstatus = -1;
+		retval = -5;
+		goto error_out;
 	}
 
 	if (G->g_do_debug_events)
 		swicol_show_events_to_fd(swicol, STDERR_FILENO, -1);
 
-	/* Now we must merge the state, creat_time, mod_time and scripts
-	   results from INSTALLED into the (SWI*)swi object so that
-	   when INSTALLED is updated it will not loose information */
-
-	/* swheader_print_header(isf_header); */
-	/* fprintf(stderr, "xxstatus is %d\n", xxstatus); */
+	if (swi) {
+		/* Now we must merge the state, creat_time, mod_time and scripts
+		   results from INSTALLED into the (SWI*)swi object so that
+		   when INSTALLED is updated it will not loose information */
 	
+		/* swheader_print_header(isf_header); */
+		/* fprintf(stderr, "xxstatus is %d\n", xxstatus); */
+		
+		E_DEBUG("HERE");
+	
+		/* Create the CISF_PRODUCT object
+		*/	
+		E_DEBUG("HERE");
+		current_product = swi_package_get_product(swi->swi_pkgM, D_ZERO /* the first one */);
+		cisf_product = swpl_cisf_product_create(current_product);
+	
+		E_DEBUG("HERE");
+		/*  Now apply selection, which for now is to assume one product and one fileset */
+		swpl_cisf_init_single_single(cisf_product, swi);
+		
+		E_DEBUG("HERE");
+		/* Now make the array of the base structure for the list of filesets in cisf_product */
+		swpl2_audit_cisf_bases(G, swi, cisf_product);
+	} else {
+		;
+	}
+
 	E_DEBUG("HERE");
-
-	/* Create the CISF_PRODUCT object
-	*/	
-	current_product = swi_package_get_product(swi->swi_pkgM, D_ZERO /* the first one */);
-	cisf_product = swpl_cisf_product_create(current_product);
-
-	/*  Now apply selection, which for now is to assume one product and one fileset */
-	swpl_cisf_init_single_single(cisf_product, swi);
-	
-	/* Now make the array of the base structure for the list of filesets in cisf_product */
-	swpl2_audit_cisf_bases(G, swi, cisf_product);
-
 	/* Create the SWHEADER of the INSTALLED file
 	*/
 	isf_header = swicat_e_isf_parse(e, &xxstatus, isf_ahs);
-
 	/* FIXME, check xxstatus */
 
 	E_DEBUG("HERE");
@@ -1460,9 +1491,9 @@ swconfig_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 			SWICOL_TL_8,
 			SW_SUCCESS);
 		if (ret != 0) {
-			looper_abort(G, swicol, ofd);
+			rstatus = -2;
+			retval = -8;
 			goto error_out;
-			retval = -1;
 		}
 	} else {
 		ret = swpl_unpack_catalog_tarfile(G, swi, ofd,
@@ -1471,9 +1502,9 @@ swconfig_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 			0 /*alt_catalog_root*/,
 			G->g_swi_event_fd);
 		if (ret != 0) {
-			looper_abort(G, swicol, ofd);
+			rstatus = -3;
+			retval = -9;
 			goto error_out;
-			retval = -1;
 		}
 	}
 
@@ -1485,9 +1516,10 @@ swconfig_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 	ret = swpl_send_nothing_and_wait(swicol, ofd, G->g_swi_event_fd, SWBIS_TS_Analysis_002,
 		SWICOL_TL_8, SW_SUCCESS);
 	if (ret != 0) {
-		looper_abort(G, swicol, ofd);
+		E_DEBUG("");
+		rstatus = -4;
+		retval = -10;
 		goto error_out;
-		retval = -1;
 	}
 
 	/* Need to set the product or fileset state to transient */
@@ -1506,9 +1538,9 @@ swconfig_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 			SWICOL_TL_8,
 			SW_SUCCESS);
 		if (ret != 0) {
-			looper_abort(G, swicol, ofd);
+			rstatus = -5;
+			retval = -11;
 			goto error_out;
-			retval = -1;
 		}
 	} else {
 		/* write the installed file */
@@ -1520,13 +1552,12 @@ swconfig_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 			G->g_swi_event_fd,
 			SWBIS_TS_Load_INSTALLED_transient, SW_A_INSTALLED, NULL);
 		if (ret != 0) {
-			looper_abort(G, swicol, ofd);
+			rstatus = -6;
+			retval = -12;
 			goto error_out;
-			retval = -1;
 		}
 	}
 
-
 	/* SWBIS_TS_run_configure */
 	if (
 		G->g_opt_previewM ||
@@ -1540,28 +1571,18 @@ swconfig_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 			SWICOL_TL_8,
 			SW_SUCCESS);
 		if (ret != 0) {
-			looper_abort(G, swicol, ofd);
+			rstatus = -7;
+			retval = -13;
 			goto error_out;
-			retval = -1;
 		}
-
-		/* Testing area */
-		if (0) {
-			STROB * xxbuf = strob_open(32);
-			construct_execution_phase_script(G, cisf_product, swi, xxbuf, config_msg); 
-			swlib_tee_to_file("/tmp/execution_phase_script.sh", -1, strob_str(xxbuf), -1, 0);
-			strob_close(xxbuf);
-		}
-		/* End of Testing area */
 	} else {
 		E_DEBUG("run configure: really running it");
 		ret = do_run_configure(G, swi, target_path, isf_header, cisf_product, swicol, e, ofd, config_msg);
 		if (ret < 0) {
 			/* internal error */
 			E_DEBUG("internal error");
-			rstatus = 8;
-			retval = -1;
-			looper_abort(G, swicol, ofd);
+			rstatus = -8;
+			retval = -14;
 			goto error_out;
 		} else if (ret > 0) {
 			/* script error */
@@ -1589,9 +1610,9 @@ swconfig_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 			SWICOL_TL_8,
 			SW_SUCCESS);
 		if (ret != 0) {
-			looper_abort(G, swicol, ofd);
+			rstatus = -10;
+			retval = -15;
 			goto error_out;
-			retval = -1;
 		}
         } else {
                 /* TS_Catalog_dir_remove */
@@ -1602,9 +1623,9 @@ swconfig_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 			0 /*alt_catalog_root*/,
 			G->g_swi_event_fd);
 		if (ret != 0) {
-			looper_abort(G, swicol, ofd);
+			rstatus = -12;
+			retval = -16;
 			goto error_out;
-			retval = -1;
 		}
 	}
 
@@ -1619,9 +1640,9 @@ swconfig_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 			SWICOL_TL_8,
 			SW_SUCCESS);
 		if (ret != 0) {
-			looper_abort(G, swicol, ofd);
+			rstatus = -13;
+			retval = -17;
 			goto error_out;
-			retval = -1;
 		}
         } else {
                 /* SWBIS_TS_Load_INSTALLED_90 */
@@ -1652,9 +1673,9 @@ swconfig_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 			G->g_swi_event_fd,
 			SWBIS_TS_Load_INSTALLED_90, SW_A__INSTALLED, isf_ahs);
 		if (ret != 0) {
-			looper_abort(G, swicol, ofd);
+			rstatus = -14;
+			retval = -18;
 			goto error_out;
-			retval = -1;
 		}
 	}
 
@@ -1669,23 +1690,23 @@ swconfig_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 			SWICOL_TL_8,
 			SW_SUCCESS);
 		if (ret != 0) {
-			looper_abort(G, swicol, ofd);
-			goto error_out;
 			retval = -1;
+			goto error_out;
 		}
         } else {
 		ret = swpl_run_make_installed_live(G, swi, ofd, target_path);
 		if (ret != 0) {
-			looper_abort(G, swicol, ofd);
+			rstatus = -15;
+			retval = -19;
 			goto error_out;
-			retval = -1;
 		}
 	}
 
 	E_DEBUG("BEFORE error_out");
 	error_out:
 	E_DEBUG("AFTER error_out");
-
+	if (do_skip_entry)
+		*did_skip = 1;
 	strob_close(xxtmp);
 	strob_close(config_msg);
 	strob_close(btmp);
