@@ -633,7 +633,7 @@ main(int argc, char **argv)
 	pid_t source_write_pid = 0;
 	pid_t target_pump_pid = 0;
 	int is_target_local_regular_file = 0;
-	char * optionname;
+	char * optionname = NULL;
 	SWI_DISTDATA * distdataO;
 
 	int opt_level_is_set = 0;
@@ -2422,6 +2422,10 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 					swicol_set_master_alarm(swicol);
 					sw_e_msg(G, "swicol: fatal: %s:%d\n", __FILE__, __LINE__);
 				}
+				
+				if (f_retval == 0)
+					ret = swpl_send_success(swicol, target_fdar[1], G->g_swi_event_fd,
+						SWBIS_TS_Do_nothing ": testing 1234");
 
 				E_DEBUG("");
 
@@ -2478,6 +2482,10 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 				E_DEBUG("");
 				ret = swicol_rpsh_task_expect(swicol, G->g_swi_event_fd, SWICOL_TL_4);
 				E_DEBUG("done");
+				
+				if (f_retval == 0)
+					ret = swpl_send_success(swicol, target_fdar[1], G->g_swi_event_fd,
+						SWBIS_TS_Do_nothing ": testing 1234");
 
 			} else if (
 				BL->has_soc_attributesM > 0 ||
@@ -2523,6 +2531,15 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 					response_img = NULL;
 				}
 
+				/* send another dummy taak */
+				/* This seems to be important for remote operations.
+				   It may have a benificial side effect of making the
+				   ``read line'' in shell_lib.sh shls_looper actually receive
+				    what was written by atomicio() in swlist_looper_sr_payload() */
+				if (f_retval == 0)
+					ret = swpl_send_success(swicol, target_fdar[1], G->g_swi_event_fd,
+						SWBIS_TS_Do_nothing ": testing 1234");
+
 				/* Now parse the response */
 				sl = NULL;
 				req = swpl_analyze_samepackage_query_response(G, response_img, &sl);
@@ -2621,7 +2638,8 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 							E_DEBUG("");
 							if (
 								rp_status != SWP_RP_STATUS_NO_INTEGRITY &&
-								rp_status != SWP_RP_STATUS_NO_LOCK
+								rp_status != SWP_RP_STATUS_NO_LOCK &&
+								rp_status != SWP_RP_STATUS_NO_PERMISSION
 							) {
 								sw_e_msg(G, "SW_INTERNAL_ERROR: %s:%d rp_status=%d\n",
 									__FILE__, __LINE__, rp_status);
@@ -2708,6 +2726,11 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 				} else {
 					reqs_failed = 0;
 				}
+
+				if (f_retval == 0)
+					ret = swpl_send_success(swicol, target_fdar[1], G->g_swi_event_fd,
+						SWBIS_TS_Do_nothing ": testing 1234");
+
 			} else {
 				E_DEBUG("ELSE LADDER DEFAULT");
 				E_DEBUG("");
@@ -2834,14 +2857,20 @@ ENTER_WITH_FAILURE:
 				G->g_pid_array_len,
 				SIGTERM,
 				G->g_verboseG);
+			sleep(1);
+			swlib_kill_all_pids(G->g_pid_array +
+				SWC_PID_ARRAY_LEN,
+				G->g_pid_array_len,
+				SIGKILL,
+				G->g_verboseG);
 		}
 
 		E_DEBUG("");
-		swlib_wait_on_all_pids(
+		swlib_wait_on_all_pids_with_timeout(
 				G->g_pid_array, 
 				G->g_pid_array_len, 
 				G->g_status_array, 0 /*waitpid flags*/, 
-				G->g_verboseG - 2);
+				G->g_verboseG - 2, -3);
 		E_DEBUG("");
 
 		if (f_retval == 0) {
