@@ -77,6 +77,7 @@ class swExStruct_i: public swExStruct
 	static int filesFdM;		// catalog/dfiles/files file list.
 	static char * filesM;		// The pointer to the list of files.
   	static int verboseM;		// the -x verbose=LEVEL value.
+  	static int store_regtype_onlyM;	// 
  	static int allowAbsolutePathsM;	// 
 	static int allowMissingSourceFileM; // Used when translating RPMS.
 	static struct extendedOptions * optaM; // Options structure from main()
@@ -151,6 +152,9 @@ class swExStruct_i: public swExStruct
 	
 	void setCreateTime(time_t tm) { current_timeM = tm; }
 	
+	void setStoreRegTypeOnly(int c) { store_regtype_onlyM = c; }
+	int getStoreRegTypeOnly(void) { return store_regtype_onlyM; }
+	
 	void setVerboseLevel(int c) { verboseM = c; }
 	
 	int getVerboseLevel(void) { return verboseM; }
