@@ -1,6 +1,6 @@
 /* swextendeddef.h  -- Process PSF Extended Definitions.
 
- Copyright (C) 2003,2004,2005,2007 Jim Lowe
+ Copyright (C) 2003,2004,2005,2007,2010 Jim Lowe
  All Rights Reserved.
   
  COPYING TERMS AND CONDITIONS:
@@ -117,6 +117,8 @@ class swExtendedDef : private swMetaData
 	int did_open_swvarfsM;
 	struct stat stM;		// Utility buffer.
 
+	int follow_symlinksM;
+
 	static const int EXPSET = 2;
 	// ===============================================================================
 	// ===============================================================================
@@ -169,6 +171,13 @@ public: // =====================================================================
 
 	// Public
 	//
+	void
+	set_follow_symlinks(int s)
+	{
+		SWEXTDEF_DEBUG("ENTER");
+		follow_symlinksM = s;
+	}
+	
 	void
 	set_digests2_creation(int s)
 	{
@@ -259,6 +268,7 @@ public: // =====================================================================
 		char * dir_source;
 		char * rel_path;
 		char * path;
+		char * old_follow_state;
 		int ret=0;
 
 		SWEXTDEF_DEBUG("");
@@ -289,6 +299,13 @@ public: // =====================================================================
 			}
 		}
 
+		old_follow_state = swvarfs_get_stat_syscall(swvarfs);
+
+		SWEXTDEF_DEBUG2("follow_symlinks is %d", follow_symlinksM);
+		if (follow_symlinksM) {
+			swvarfs_set_stat_syscall(swvarfs, "stat" /* stat or lstat */);
+		}
+
 		//
 		// 5.2.13.1  line 771  make sure it exists.
 		//
@@ -298,8 +315,10 @@ public: // =====================================================================
 			/*
 			* FIXME If sourcing on an archive ignore "."... Because it doesn't work
 			*/
+			SWEXTDEF_DEBUG("running swvarfs_get_next_dirent");
 			path = swvarfs_get_next_dirent(swvarfs, &st);
 		} else {
+			SWEXTDEF_DEBUG2("running local_lstat_swvarfs on path: %s", path);
 			if (local_lstat_swvarfs(path, &st) < 0) {
 				fprintf(stderr,"swpackage: lstat error [%s] : %s\n", path, errno ? strerror(errno) : "");
 				return -3;
@@ -326,6 +345,7 @@ public: // =====================================================================
 			//
 			// translate spaces to non-break space 0xa0
 			//
+			SWEXTDEF_DEBUG2("while path loop: path=%s", path);
 			protect_space(path);
 			
 			//
@@ -343,8 +363,10 @@ public: // =====================================================================
 				path = "./";
 			}
 			
+			SWEXTDEF_DEBUG("");
 			ret = processExplicitFile_i(path, swdef, &st, 1, 1, NULL);
 			if (ret == 0) {
+				SWEXTDEF_DEBUG("");
 				assert(swdefFormedM);
 				swdefFormedM->set_no_stat(1);
 				recursive_list_unique_add(psf, swdefFormedM);
@@ -365,6 +387,8 @@ public: // =====================================================================
 			}
 			path = swvarfs_get_next_dirent(swvarfs, &st);
 		}
+		
+		swvarfs_set_stat_syscall(swvarfs, old_follow_state);
 
 		if (did_open_swvarfsM) {
 			SWEXTDEF_DEBUG("");
@@ -430,6 +454,7 @@ public: // =====================================================================
 				// Check to see if path attribute matches any previous files, and if
 				// so merge the attributes.  (Duplicate files).
 				//
+				SWEXTDEF_DEBUG("");
 				if ((prior_file = find_same_prior_file(psf, swdefFormedM, -1)) != NULL) {
 					SWEXTDEF_DEBUG("");
 					#ifdef SWEXTDEFNEEDDEBUG
@@ -461,7 +486,7 @@ public: // =====================================================================
 	// Public
 	//
 	int
-	attach_filePaths(swDefinition * swdef, char * source_att, char * source, char * path){
+	attach_filePaths(swDefinition * swdef, char * source_att, char * source, char * path) {
 		int level = swdef->get_level() + 1;
 		int mem_fd = swdef->get_mem_fd();
 		swAttribute * swatt;
@@ -486,7 +511,7 @@ public: // =====================================================================
 	// Public
 	//
 	int
-	processExtendedControl_file(char * keyword, char * value, swDefinition * parent_swdef){
+	processExtendedControl_file(char * keyword, char * value, swDefinition * parent_swdef) {
 		int level = parent_swdef->get_level();
 		char * source, *path;
 		swAttribute * swatt;
@@ -562,7 +587,7 @@ public: // =====================================================================
 	// file [-t type] [-m mode] [-o [owner[,]][uid]] [-g [group[,]][gid]] [-n] [-v] source [path]
 	//
 	int
-	processExplicitFile(char * value, swDefinition * parent_swdef){
+	processExplicitFile(char * value, swDefinition * parent_swdef) {
 		int do_no_stat = 1;
 		int ret = processExplicitFile_i(value, parent_swdef, static_cast<struct stat *>(NULL), 1, 0, &do_no_stat);
 		// The NULL st buf causes the stat to be done in stat_source_file_if().
@@ -1096,6 +1121,7 @@ private: // ================================================================
 		do_create_sha2M = 0;
 		did_open_swvarfsM = 0;
 		non_existing_sourceM = 0;
+		follow_symlinksM = 0;
 	}
 
 	void
@@ -1317,12 +1343,14 @@ private: // ================================================================
 			// return NULL;
 		}
 
+		SWEXTDEF_DEBUG("entering while loop");
 		while (
 			(stop_index  < 0 || list_index < stop_index) &&
 			(swdef=psf->swdeffile_get_pointer_from_index(list_index++)) != 
 				static_cast<swDefinition*>(NULL)
 		)
 		{
+			SWEXTDEF_DEBUG("in while loop");
 			if(strcmp("file", swdef->get_keyword())) {
 				// 
 				// skip objects that are not file objects.
@@ -1805,10 +1833,14 @@ private: // ================================================================
 
 		//
 		// Verifies that the value is all digits.
+		// returns number of digits, -1 on error
 		//
 
 		while (*w  &&  isdigit(*w)) w++;
-		if (*w == '\0' || strchr(terminating_chars, *w)) return 0;
+		if (*w == '\0' || strchr(terminating_chars, *w)) {
+			return (int)(w-value);
+		}
+
 		return -1;
 	}
 	
@@ -1816,11 +1848,17 @@ private: // ================================================================
 	// Parse the Explicit File Option value.
 	//	
 	char *
-	bound_value(char * value, char ** aux, int id_test) {
+	bound_value(char * value, char ** aux, int *p_has_comma) {
 		char *s=value;
 		char *w;
 	
+		SWEXTDEF_DEBUG2("BEGIN value=[%s]", value);
 		if (aux) *aux = NULL;
+		if (p_has_comma) *p_has_comma = 0;
+
+		//
+		// skip over leading spaces
+		//
 		while (isspace((int)(*s))){ s++; }
 		w = s;
 		if (*s == '-') {
@@ -1830,18 +1868,54 @@ private: // ================================================================
 			//
 			s--;
 			*s = '\0';
+			SWEXTDEF_DEBUG2("aux = [%s]", (aux!=NULL ? *aux : ""));
 			return s;
 		}
+
+		//
+		// march down the value (atom) until a separator is encounterd
+		//
+
 		while (*w  &&  *w != '\x20'  &&  *w != '\x09' && *w != ',') w++;
-		
+	
+		//
+		// If the separator was a ',' then record the pointer
+		//
+	
 		if (aux) {
 			if (*w == ',') {
-				*aux = w+1;
+				if (p_has_comma) {
+					*p_has_comma = 1;
+				}
+				if (*(w+1) == '\x20' || *(w+1) == '\x09') {
+					//
+					// case for 
+					// file -o owner,
+					//
+					// Here, the numeric id is not givem
+					// return it as an empty string by leaving
+					// *aux set to *w, (*w will become '/0').
+					//
+					*aux = w;
+				} else	{
+					//
+					// case for 
+					// file -o owner,uid
+					//
+					// *w, which is now ',', will become NUL.
+					// Here we are intensionally stepping
+					// past a (to be) '\0' terminator because
+					// then next atom is presumably the all-digits
+					// numeric system id.
+					//
+					*aux = w+1;
+				}
 			} else {
 				*aux = NULL;
 			}
 		}
 		*w = '\0';
+		SWEXTDEF_DEBUG2("aux = [%s]", (aux!=NULL ? *aux : ""));
 		return s;
 	}
 
@@ -1852,15 +1926,23 @@ private: // ================================================================
 				int idix,
 				char array[][file_permsLength],
 				int array_is_set[],
-				int * p_skip_amount
+				int * p_skip_amount,
+				int has_comma
 			)
 	{
-		SWEXTDEF_DEBUG("");
+		int ret;
+		char * val;
+		STROB * vxa;
+
+		SWEXTDEF_DEBUG2("BEGIN value=[%s]", value);
+		SWEXTDEF_DEBUG2("BEGIN aux_value=[%s]", aux_value ? aux_value: "<nil>");
 		
+		vxa = NULL;
 		copy_file_cell(array, array_is_set, idix, NULL);
 		copy_file_cell(array, array_is_set, nameix, NULL);
 		
 		if (strlen(value) == 0) {
+			SWEXTDEF_DEBUG2("value=[%s]", value);
 			if (is_file_perm) {
 				//
 				// Section 5.2.13.4 Line 886
@@ -1879,55 +1961,119 @@ private: // ================================================================
 				return 2;	
 			}
 		} else {
-			if (
-				(check_is_all_digits(value, " ,") == 0) &&
-				aux_value == NULL
-			) {
+			//
+			// value is not 0 length
+			//
+			SWEXTDEF_DEBUG2("value=[%s]", value);
+			ret = check_is_all_digits(value, " ,");
+			if ( ret > 0 && aux_value == NULL) {
 				//
-				// If in this context, the primary arg
-				// is a uid if is has all digits.
+				// value has all digits, treat it
+				// as a uid.
 				//
 				// Section 5.2.13.3 Lines 853-877.
 				//	
 				SWEXTDEF_DEBUG("");
+				SWEXTDEF_DEBUG("handling -o uid");
 				copy_file_cell(array, array_is_set, idix, value);
 				if (is_file_perm == 0) {
 					SWEXTDEF_DEBUG("not is_file_permissions_context");
 					array_is_set[idix] = EXPSET;
 				}
 				copy_file_cell(array, array_is_set, nameix, TARU_C_DO_NUMERIC);
-			} else {
+			} else if ( ret < 0 && aux_value == NULL) {
+				//
+				// Here the value is not all digits and there is
+				// no aux_value.
+				// This handles the case of `-o owner'
+				//
 				SWEXTDEF_DEBUG("");
+				SWEXTDEF_DEBUG("handling -o owner");
 				copy_file_cell(array, array_is_set, nameix, value);
 				if (is_file_perm == 0) {
 					SWEXTDEF_DEBUG("not is_file_permissions_context");
 					array_is_set[nameix] = EXPSET;
 				}
+			} else if ( ret < 0 && aux_value != NULL && has_comma == 1) {
+				//
+				// This handles the case of `-o owner,uid' and set the
+				// value for the case of `-o owner,' where the setting of
+				// the implied uid is set below
+				//
+				SWEXTDEF_DEBUG2("handling -o owner,uid  value=%s", value);
+				copy_file_cell(array, array_is_set, nameix, value);
+				if (is_file_perm == 0) {
+					SWEXTDEF_DEBUG("not is_file_permissions_context");
+					array_is_set[nameix] = EXPSET;
+				}
+			} else if ( ret == 0 && aux_value == NULL) {
+				//
+				// This will never happen the the strlen(value) was
+				// tested above.
+				//
+				fprintf(stderr, "swpackage: internal error 13 in swextendeddef.h\n");
+				exit(1);	
 			}
 		}
 		*p_skip_amount = strlen(value);
 		if (aux_value && strlen(aux_value)) {
-			if 
-			(
-				check_is_all_digits(aux_value + 1, " ") != 0
-			)
-			{
-					//
-					// Error, not all digits.
-					//
-					fprintf(stderr, "swpackage: invalid uid in extended definition.\n");
-					return 1;
+			SWEXTDEF_DEBUG2("aux_value is [%s]", aux_value);
+			ret = check_is_all_digits(aux_value, " ");
+			val = NULL;
+			if ( ret < 0) {
+				//
+				// Error, not all digits.
+				//
+				fprintf(stderr, "swpackage: invalid uid in extended definition.\n");
+				return 1;
+			} else if (ret == 0 && has_comma) {
+				//
+				// This is the case of for example
+				//    -o admin, -g admin,
+				// Here, get the uid of the user name and use it as if
+				// it was specified.
+				//
+				SWEXTDEF_DEBUG2("looking up id for [%s]", value);
+				uid_t xid;	
+				if (taru_get_uid_by_name(value, &xid) < 0) {
+					fprintf(stderr, "swpackage: user name not in system: %s\n", value);
+					fprintf(stderr, "swpackage: setting id to nobody\n");
+					if (taru_get_uid_by_name(AHS_USERNAME_NOBODY, &xid) < 0) {
+						fprintf(stderr, "swpackage: %s name not in system\n", AHS_USERNAME_NOBODY);
+						fprintf(stderr, "swpackage: setting id to %d\n", (int)AHS_UID_NOBODY);
+						xid = (uid_t)AHS_UID_NOBODY;
+					}
+				}
+				if (vxa == NULL)
+					vxa = strob_open(12);
+				SWEXTDEF_DEBUG3("Found id as [%d] for name [%s]", (int)xid, value);
+				strob_sprintf(vxa, 0, "%d", (int)xid);
+				val = strob_str(vxa);
+			} else if (ret == 0 && !has_comma) {
+				fprintf(stderr, "swpackage: invalid uid in extended definition.\n");
+				return 1;
+			} else if (ret > 0) {
+				//
+				// This is the normal case, the user supplied a number after the comma
+				//
+				val = bound_value(aux_value, (char**)NULL, (int*)NULL);
+			} else {
+				//
+				// Never gets here
+				return -2;
 			}
 			SWEXTDEF_DEBUG("aux value");
-			value = bound_value(aux_value, NULL, 0);
-			copy_file_cell(array, array_is_set, idix, value);
+			SWEXTDEF_DEBUG2("setting from aux value, [%s]", val);
+			copy_file_cell(array, array_is_set, idix, val);
 			if (is_file_perm == 0) {
+				SWEXTDEF_DEBUG2("is_file_perm == 0, setting array_is_set[%d] = EXPSET", idix);
 				array_is_set[idix] = EXPSET;
 			}
 			(*p_skip_amount) ++;  	// Skip over the comma.
-			(*p_skip_amount) += strlen(value);
+			(*p_skip_amount) += strlen(val);
+			if (vxa) strob_close(vxa);
 		}
-		return 0;	
+		return 0;
 	}
 
 	//
@@ -1947,8 +2093,10 @@ private: // ================================================================
 		int did_umode = 0;
 		int umask_value;
 		int ret;
+		int has_comma;
 
 		SWEXTDEF_DEBUG("");
+		aux_value = NULL;
 		if (array == fileDefPermsArrayM) {
 			//
 			// The syntax for 'file_permissions' keyword is slightly different.
@@ -1972,7 +2120,7 @@ private: // ================================================================
 					case 't':
 						SWEXTDEF_DEBUG("");
 						p+=2;  // Step over the option letter and a space.
-						value = bound_value(p, &aux_value, 0);
+						value = bound_value(p, (char**)NULL, (int*)NULL);
 						copy_file_cell(array, array_is_set, typeE, value);
 						array_is_set[typeE] = EXPSET;
 						skip_amount = strlen(value);
@@ -1981,7 +2129,7 @@ private: // ================================================================
 					case 'm':
 						SWEXTDEF_DEBUG("");
 						p+=2;
-						value = bound_value(p, &aux_value, 0);
+						value = bound_value(p, (char**)NULL, (int*)NULL);
 						if (is_file_permissions_context) {
 							if (did_umode) {
 								fprintf(stderr, "swpackage: either mode or umask may be specified.\n");
@@ -1991,7 +2139,7 @@ private: // ================================================================
 							}
 							did_umode = 1;
 						}
-						if (strlen(value) == 0 || check_is_all_digits(value, " ")) {
+						if (strlen(value) == 0 || check_is_all_digits(value, " ") < 0) {
 							fprintf(stderr, "swpackage: invalid mode [%s].\n", value);
 							error_code = 2;
 						}
@@ -2010,7 +2158,7 @@ private: // ================================================================
 						//
 						SWEXTDEF_DEBUG("");
 						p+=2;
-						value = bound_value(p, &aux_value, 0);
+						value = bound_value(p, &aux_value, &has_comma);
 						skip_amount = 0; // this to avoid a warning
 						ret = parse_name_id_string(value, aux_value,
 								is_file_permissions_context, 
@@ -2018,7 +2166,7 @@ private: // ================================================================
 								uidE,
 								array,
 								array_is_set,
-								&skip_amount);
+								&skip_amount, has_comma);
 						if (ret) {
 							error_code = 4;
 						}
@@ -2026,14 +2174,14 @@ private: // ================================================================
 					case 'g':
 						SWEXTDEF_DEBUG("");
 						p+=2;
-						value = bound_value(p, &aux_value, 0);
+						value = bound_value(p, &aux_value, &has_comma);
 						ret = parse_name_id_string(value, aux_value,
 								is_file_permissions_context, 
 								groupE,
 								gidE,
 								array,
 								array_is_set,
-								&skip_amount);
+								&skip_amount, has_comma);
 						if (ret) {
 							error_code = 4;
 						}
@@ -2041,7 +2189,7 @@ private: // ================================================================
 					case 'u':
 						SWEXTDEF_DEBUG("");
 						p+=2;
-						value = bound_value(p, &aux_value, 0);
+						value = bound_value(p, (char**)NULL, (int*)NULL);
 						if (!is_file_permissions_context) {
 							//
 							// Error.
@@ -2173,16 +2321,17 @@ private: // ================================================================
 		mode_t default_umask = 022;
 		struct stat stbuf;
 		struct stat *st;
-		SWEXTDEF_DEBUG("");
+		SWEXTDEF_DEBUG2("Begin: source: %s", source);
 	
 		retval = 0;
 		if (sti != static_cast<struct stat*>(NULL)) {
-			SWEXTDEF_DEBUG("");
+			SWEXTDEF_DEBUG("sti is NULL");
 			st = sti;
 		} else {
 			SWEXTDEF_DEBUG("");
 			st = &stbuf;
 			if (source) {
+				SWEXTDEF_DEBUG2("running local_lstat_swvarfs() on source: %s", source);
 				if (local_lstat_swvarfs(source, st)) {
 					fprintf(stderr,"swpackage: stat error: %s\n", source);
 					return -1;
@@ -2201,7 +2350,7 @@ private: // ================================================================
 			//
 			// Set some default attribute values based on the type.
 			//
-			SWEXTDEF_DEBUG("");
+			SWEXTDEF_DEBUG("source is NULL");
 			p_mode = get_stat_cell_pointer(modeE);
 			p_minor = get_stat_cell_pointer(minorE);
 			p_major = get_stat_cell_pointer(majorE);
@@ -2255,6 +2404,7 @@ private: // ================================================================
 				cksumflags |= SWFILE_DO_FILE_DIGESTS_SHA2;
 			}
 	
+			SWEXTDEF_DEBUG("");
 			init_statArray();
 
 			if (hl_path && strlen(hl_path)) {
@@ -2263,6 +2413,7 @@ private: // ================================================================
 				hlif_path = source;
 			}
 
+			SWEXTDEF_DEBUG("Entering swmetadata_decode_file_stats");
 			retval = swmetadata_decode_file_stats(swvarfsM, source,
 				hlif_path, st, statArrayM,
 				statArrayWasSetM, cksumflags);
@@ -2344,7 +2495,7 @@ private: // ================================================================
 	// definitions if required.
 	//
 	int 
-	generate_ExplicitFileAttributes(char * source, char * hl_path, struct stat *st, int do_stat) {
+	generate_ExplicitFileAttributes(char * source, char * hl_path, struct stat *stpo, int do_stat) {
 		int retval;
 		int ret;
 		int i;
@@ -2354,6 +2505,8 @@ private: // ================================================================
 		unsigned int ui_mode;
 		
 		retval = 0;
+		SWEXTDEF_DEBUG("Begin");
+		SWEXTDEF_DEBUG2("source=[%s]", source);
 		//
 		// Section 5.2.13.3
 		// Lines 810-812.  If file_permissions keyword is active ...
@@ -2367,8 +2520,9 @@ private: // ================================================================
 			file_cell_was_explicitly_set(groupE)
 		    )
 		) {
-			SWEXTDEF_DEBUG("");
+			SWEXTDEF_DEBUG("filePermissionsActiveM and perms were explicitly set");
 			for (i=0; i<lastE; i++) {
+				SWEXTDEF_DEBUG("transferring from defaults array");
 				//
 				// Transfer the values from defaults array to explicit array.
 				// if not already set.
@@ -2383,13 +2537,14 @@ private: // ================================================================
 		} 
 
 		if (do_stat) {
-			SWEXTDEF_DEBUG("");
-			ret = stat_source_file_if(source, hl_path, st);
+			SWEXTDEF_DEBUG("in do_stat");
+			ret = stat_source_file_if(source, hl_path, stpo);
 			if (ret < 0) {
 				fprintf(stderr,"swpackage: stat_source_file_if returned error.\n");
 				exit(2); // FIXME
 			} else if (ret > 0) {
 				// ignore socket
+				SWEXTDEF_DEBUG("ignoring socket");
 				retval = ret;
 			} else {
 				retval = ret;
@@ -2405,6 +2560,7 @@ private: // ================================================================
 			file_cell_was_explicitly_set(groupE)
 		    )
 		) {
+			SWEXTDEF_DEBUG("AGAIN: filePermissionsActiveM and perms were explicitly set");
 			SWEXTDEF_DEBUG("");
 			if (fileArrayWasSetM[modeE] == 0 && fileDefPermsArrayWasSetM[umaskE]) {
 				//
@@ -2418,7 +2574,7 @@ private: // ================================================================
 				// If not explicitly set then make up a mode '666' or '777'
 				//
 
-				SWEXTDEF_DEBUG("");
+				SWEXTDEF_DEBUG("applying umask");
 				sscanf(fileDefPermsArrayM[umaskE], "%o", &ui_def_umask);
 				def_umask = (mode_t)ui_def_umask;
 				if (statArrayWasSetM[modeE]) {
@@ -2445,7 +2601,7 @@ private: // ================================================================
 		// the statArrayWasSetM[i] to zero.
 		//
 
-		SWEXTDEF_DEBUG("");
+		SWEXTDEF_DEBUG("transfer from stat array");
 		handle_ownerships(fileArrayM, fileArrayWasSetM, statArrayM, statArrayWasSetM, ownerE, uidE);
 		handle_ownerships(fileArrayM, fileArrayWasSetM, statArrayM, statArrayWasSetM, groupE, gidE);
 
@@ -2701,9 +2857,10 @@ private: // ================================================================
 		char * path;
 		char * o_source;
 		char * o_path;
+		char * old_follow_state;
 
 
-		SWEXTDEF_DEBUG("");
+		SWEXTDEF_DEBUG2("Begin: [%s]", value);
 		strob_strcpy(file_pathM, "");
 		strob_strcpy(file_linksource_pathM, "");
 
@@ -2719,9 +2876,12 @@ private: // ================================================================
 			strob_strcpy(file_pathM, value);
 			return -1;
 		}
+		SWEXTDEF_DEBUG2("source_path=[%s]", source_path);
 		SWEXTDEF_DEBUG("");
 		parse_SourcePath(source_path, &source, &path);
 		SWEXTDEF_DEBUG("");
+		SWEXTDEF_DEBUG2("source=[%s]", source);
+		SWEXTDEF_DEBUG2("path=[%s]", path);
 	
 		unprotect_space(source);
 		unprotect_space(path);
@@ -2831,17 +2991,27 @@ private: // ================================================================
 		swlib_squash_embedded_dot_slash(source);
 		SWEXTDEF_DEBUG3("type path=[%s] source=[%s]", path, source);
 		SWEXTDEF_DEBUG3("type o_path=[%s] o_source=[%s]", o_path, o_source);
-		SWEXTDEF_DEBUG("");
+		SWEXTDEF_DEBUG("HERE before main else ladder");
 		if (fileArrayWasSetM[typeE] == 0) {
+			SWEXTDEF_DEBUG("fileArrayWasSetM[typeE] == 0)");
+			old_follow_state = swvarfs_get_stat_syscall(swvarfsM);
+			if (follow_symlinksM) {
+				swvarfs_set_stat_syscall(swvarfsM, "stat" /* stat or lstat */);
+			}
 			attach_filePaths(swdef, SW_A_source, source, path);
+			SWEXTDEF_DEBUG("Entering generate_ExplicitFileAttributes");
 			ret = generate_ExplicitFileAttributes(source, source, st, 1);
-			if (ret < 0) return -1;
+			swvarfs_set_stat_syscall(swvarfsM, old_follow_state);
+			if (ret < 0) {
+				return -1;
+			}
 			if (ret > 0) {
 				// ignore file, such as a socket
 				delete swdef;
 				swdefFormedM = NULL;
 				return 1;
 			}
+			SWEXTDEF_DEBUG("end of fileArrayWasSetM[typeE] == 0");
 		} else if (fileArrayM[typeE][0] == SW_ITYPE_d) {
 			//
 			// 5.2.13.3: Lines 831-836.
@@ -2920,8 +3090,9 @@ private: // ================================================================
 				if (apply_default_values(fileArrayM[typeE][0]))
 					return -1;
 			}
+			SWEXTDEF_DEBUG("Entering generate_ExplicitFileAttributes");
 			if (generate_ExplicitFileAttributes(source, source, st, !(*do_no_stat)) < 0) return -1;
-		} else if (fileArrayM[typeE][0] == SW_ITYPE_h) {	
+		} else if (fileArrayM[typeE][0] == SW_ITYPE_h) {
 			//
 			// Hard Link: 5.2.13.3: Lines 837-840.
 			//
@@ -2987,9 +3158,10 @@ private: // ================================================================
 
 			attach_filePaths(swdef, "link_source", strob_str(file_linksource_pathM), (char*)(NULL));
 			attach_filePaths(swdef, SW_A_source, o_source, strob_str(file_pathM));
+			SWEXTDEF_DEBUG("Entering generate_ExplicitFileAttributes");
 			if (generate_ExplicitFileAttributes(source, (char *)NULL, st, !(*do_no_stat)) < 0) return -1;
 
-		} else if (fileArrayM[typeE][0] == SW_ITYPE_s) {	
+		} else if (fileArrayM[typeE][0] == SW_ITYPE_s) {
 			//
 			// Symbolic link: 5.2.13.3: Lines 841-844
 			//
@@ -3014,9 +3186,10 @@ private: // ================================================================
 			if (apply_default_values(fileArrayM[typeE][0]))
 				return -1;
 			copy_file_cell(fileArrayM, fileArrayWasSetM, modeE, "0777");
+			SWEXTDEF_DEBUG("Entering generate_ExplicitFileAttributes");
 			if (generate_ExplicitFileAttributes(source, (char*)NULL, st, 0) < 0) return -1;
 			if (do_no_stat) *do_no_stat = 1;
-		} else {	
+		} else {
 			fprintf(stderr, "swpackage: bad file type in PSF file : '%s'.\n", fileArrayM[typeE]);
 			return -1;
 		}
