@@ -51,6 +51,8 @@ extern "C" {
 }
 
 // #define SWPACKAGEFILENEEDDEBUG 1
+#define SWPACKAGEFILENEEDDEBUG 1
+#undef SWPACKAGEFILENEEDDEBUG 
 
 #ifdef SWPACKAGEFILENEEDDEBUG
 #define SWPACKAGEFILE_DEBUG(format) SWBISERROR("SWPACKAGEFILE DEBUG: ", format)
@@ -1168,7 +1170,7 @@ class swPackageFile :  public swAttribute
 			//
 			// Got a username
 			//
-			SWPACKAGEFILE_DEBUG("Got a user name");
+			SWPACKAGEFILE_DEBUG2("Got a user name [%s]", value);
 			if (!value2) {
 				//
 				// But no uid
@@ -1176,6 +1178,7 @@ class swPackageFile :  public swAttribute
 				SWPACKAGEFILE_DEBUG("");
 				xFormat_set_sys_db_u_policy(TARU_C_BY_UNAME);
 				xFormat_set_user_systempair(value);
+				xFormat_set_sys_db_u_policy(TARU_C_BY_UNONE);
 			} else {
 				SWPACKAGEFILE_DEBUG("");
 				if (strcmp(value, TARU_C_DO_NUMERIC) == 0) {
@@ -1210,7 +1213,7 @@ class swPackageFile :  public swAttribute
 				//
 				SWPACKAGEFILE_DEBUG("No user name and no uid");
 				xFormat_set_sys_db_u_policy(TARU_C_BY_USYS);
-				xFormat_set_group_systempair("nobody");
+				xFormat_set_group_systempair(AHS_USERNAME_NOBODY);
 			}	
 		}
 		set_find_mode_logical(logical_find);
@@ -1231,6 +1234,7 @@ class swPackageFile :  public swAttribute
 				SWPACKAGEFILE_DEBUG("");
 				xFormat_set_sys_db_g_policy(TARU_C_BY_GNAME);
 				xFormat_set_group_systempair(value);
+				xFormat_set_sys_db_g_policy(TARU_C_BY_GNONE);
 			} else {
 				SWPACKAGEFILE_DEBUG("");
 				if (strcmp(value, TARU_C_DO_NUMERIC) == 0) {
@@ -1265,7 +1269,7 @@ class swPackageFile :  public swAttribute
 				//
 				SWPACKAGEFILE_DEBUG("No group name and no gid");
 				xFormat_set_sys_db_g_policy(TARU_C_BY_GSYS);
-				xFormat_set_group_systempair("nobody");
+				xFormat_set_group_systempair(AHS_USERNAME_NOBODY);
 			}	
 		}
 		set_find_mode_logical(logical_find);
