@@ -152,6 +152,7 @@ enum eOpts {	/* NOTE: the order must match the optionsArray
 	SW_E_swbis_check_mtime,
 	SW_E_swbis_check_duplicates,
 	SW_E_swbis_check_owners,
+	SW_E_swbis_replacefiles,
 	SW_E_swbis_last_option
 	};  /* NOTE: the order must match the optionsArray
 		 found in swsupplib/misc/swcommon_options.h*/
@@ -177,7 +178,7 @@ char * get_opta(struct extendedOptions * opta, enum eOpts nopt);
 char * get_opta_isc(struct extendedOptions * opta, enum eOpts nopt);
 int parse_options_file(struct extendedOptions * opta, char * filename, char * util_name);
 char * initialize_options_files_list(char * usethis);
-int parse_options_files(struct extendedOptions * opta, char * option_files, char * util_name, int reqd, int show_only);
+int swextopt_parse_options_files(struct extendedOptions * opta, char * option_files, char * util_name, int reqd, int show_only);
 int swextopt_combine_directory(STROB * result, char * soc_spec, char * directory);
 int swextopt_get_status(void);
 void set_opta_boolean(struct extendedOptions * opta, enum eOpts nopt, char * value);
