@@ -131,6 +131,26 @@ swheaderline_get_type_pointer(char *output_line)
 	}
 }
 
+int
+swheaderline_write_to_buffer (STROB * buf,  char * line)
+{
+	char * keyword;
+	char * value;
+        int type;
+	int level;
+
+	if (!line) return -1;
+	keyword = swheaderline_get_keyword(line);
+	value =  swheaderline_get_value(line, NULL);
+        type = (int)swheaderline_get_type(line);
+	level = swheaderline_get_level(line);
+	if (keyword && strlen(keyword))	
+		return swdef_write_attribute_to_buffer(buf, keyword, value, level, (int)type);
+	else
+		return 0;
+}
+
+
 int
 swheaderline_write (char * line, int uxfio_fd)
 {
