@@ -386,9 +386,6 @@ write_query_blob(GB * G, SWVERID * swverid, STROB * buf, STROB * tmp, int query_
 	}	
 	shpat_to_regex(tmp, tmpval);
 	strob_sprintf(buf, 1, "SWBIS_INSTANCE=\"%s\"\n", strob_str(tmp));
-	/*
-	strob_sprintf(buf, 1, "SWBIS_INSTANCE=\".*\"\n");
-	*/
 
 	verid = swverid_get_verid(swverid, SWVERID_VERIDS_LOCATION, 1);
 	if (verid == NULL) {
@@ -659,7 +656,6 @@ swicat_isf_all_scripts(STROB * buf, SWI_SCRIPTS * xx, int do_if_active)
 int
 swicat_isf_control_script(STROB * buf, SWI_CONTROL_SCRIPT * xx, int do_if_active)
 {
-	/* if (do_if_active && !(xx->is_activeM)) return 0; */
 	strob_sprintf(buf, STROB_DO_APPEND, SW_A_control_file "\n");
 	strob_sprintf(buf, STROB_DO_APPEND, "\t" SW_A_tag " %s\n", xx->baseM.b_tagM);
 	strob_sprintf(buf, STROB_DO_APPEND, "\t" SW_A_result " %s\n", swi_control_script_posix_result(xx));
@@ -689,14 +685,12 @@ swicat_isf_product(SWI * swi, STROB * buf, SWI_PRODUCT * prod, int do_if_active)
 	SWHEADER * swheader;
 
 	swheader = SWI_INDEX_HEADER(swi);
-	/* if (do_if_active && !(prod->is_activeM)) return 0; */
 	strob_sprintf(buf, STROB_DO_APPEND, SW_A_product "\n");
 	strob_sprintf(buf, STROB_DO_APPEND, SW_A_location " %s\n", swi->swi_pkgM->locationM ? swi->swi_pkgM->locationM:"/");
 		
 	write_attributes(buf, SWI_INDEX_HEADER(swi), prod->p_baseM.header_indexM);
 
 	write_times(buf, (SWI_BASE *)&(prod->p_baseM), 1 /* do_if_active */);
-	/* strob_sprintf(buf, STROB_DO_APPEND, SW_A_all_filesets "%s\n", "" ); */
 
 	/* ------------------------------------------------------ */
 	/* ------------------------------------------------------ */
@@ -929,12 +923,6 @@ swicat_write_script_cases(SWI * swi, STROB * buf, char * sw_selection)
 	scripts = xfile->swi_scM;
 	SWLIB_ASSERT(scripts != NULL);   /* fatal */
 
-	/*
-	swverid_print(SWI_GET_PRODUCT(swi, 0)->p_baseM.swveridM, tmp);
-	*/
-
-	/* This swverid will become the value of SW_SOFTWARE_SPEC */
-
 	/* make a copy of the swverid to avoid harming the original */
 
 	swverid_spec = swverid_copy(SWI_GET_PRODUCT(swi, 0)->p_baseM.swveridM);
@@ -1379,10 +1367,6 @@ main(int argc, char **argv)
 	
 	memset(nuls, '\0', sizeof(nuls));
 	
-	/*
-	uxfio_write(fd, nuls, 1);
-	uxfio_write(fd, nuls, 1);
-	*/
 	uxfio_write(fd, nuls, 1);
 	s="abcdef";
 	uxfio_write(fd, s, strlen(s));
