@@ -99,13 +99,6 @@
 
 #define SWVERID_VERID_CATALOG_INSTANCE	(*(SWVERID_VERIDS_CATALOG_INSTANCE))
 
-/*
-#define SWVERID_DEPSTATUS_UNSET		-1
-#define SWVERID_DEPSTATUS_NOEXIST	0
-#define SWVERID_DEPSTATUS_EXIST		1  / * SWVERID does exist in catalog * /
-#define SWVERID_DEPSTATUS_ALTEXIST	2  / * an alternate exists * /
-*/
-
 typedef int Swverid_Cmp_Code;
 
 #define SWVERID_G_taglistM(X)  (X->taglistM)
