@@ -83,33 +83,47 @@ copyright_info(FILE * fp)
 
 static 
 void  usage (char * progname, FILE * fp) {
+    fprintf (fp, "\n");
     fprintf (fp, "Usage: lxpsf [options] [file]\n");
-    fprintf (fp, " Read any format (RPM,DEB,slackware) package and write a tar archive\n");
-    fprintf (fp, " to stdout that is able to be converted to a POSIX package by swpackage\n");
-    fprintf (fp, " when installed in the file system.  GNU swpackage has a special\n");
-    fprintf (fp, " feature to read a tar archive in memory as a file system (See below).\n");
-    fprintf (fp, "    --psf-form1  default form, full control directories (applies to RPM only).\n");
-    fprintf (fp, "    --psf-form2  include path name prefix in archive (applies to RPM only).\n");
-    fprintf (fp, "    --psf-form3  no control directories, with path name prefix (applies to RPM only).\n");
-    fprintf (fp, "    --deb-control   write uncompressed control.tar.gz tar file to stdout.\n");
-    fprintf (fp, "    --deb-data   write uncompressed data.tar.gz tar file to stdout.\n");
-    fprintf (fp, "    --create-time=cal_time  Use this time for archive header times\n");
-    fprintf (fp, "    --owner=NAME  package owner\n");
-    fprintf (fp, "    --group=NAME  package group\n");
-    fprintf (fp, "    -d, --debug-level=TYPE    always use 'link'\n");
-    fprintf (fp, "    -D checkdigest  checkdigest script, applies to plain tarball translation.\n");
-    fprintf (fp, "    -x, --use-recursive-fileset Use \"file *\" instead of individual file definitions.\n");
-    fprintf (fp, "    -r, --no-leading-path   use \".\" as the leading archive path\n");
-    fprintf (fp, "    -B buffertype   mem or file  Mem is default.\n");
-    fprintf (fp, "    -H format     archive format: ustar, newc, crc, odc\n");
-    fprintf (fp, "    -p, --psf-only   Write the PSF to stdout.\n");
-    fprintf (fp, "    -o, --info-only   Write the INFO file for the rpm archive.\n");
-    fprintf (fp, "    -r, --no-leading-path.\n");
-    fprintf (fp, "    -L, --smart-leading-path  Use leading path for srpm and not rpm.\n");
+    fprintf (fp, "\n");
+    fprintf (fp, "Read any format (RPM,DEB,slackware) package and write a tar archive\n");
+    fprintf (fp, "to stdout that is able to be converted to a POSIX package by swpackage\n");
+    fprintf (fp, "when installed in the file system.  GNU swpackage has a special\n");
+    fprintf (fp, "feature to read a tar archive in memory as a file system (See below).\n");
+    fprintf (fp, "Currently the following package formats are supported:\n");
+    fprintf (fp, "    RPM v3 (source and binary), Debian Package Format (Deb v2.0),\n");
+    fprintf (fp, "    Slackware runtime tarballs, and plain vanilla tarballs\n");
+    fprintf (fp, "\n");
+    fprintf (fp, "   --psf-form1  default form, full control directories\n");
+    fprintf (fp, "   --psf-form2  include path name prefix in archive\n");
+    fprintf (fp, "   --psf-form3  no control directories, with path name prefix\n");
+    fprintf (fp, "   --slackware-pkg-name=NAME  Tarball filename.\n");
+    fprintf (fp, "   --deb-control   write uncompressed control.tar.gz tar file to stdout.\n");
+    fprintf (fp, "   --deb-data   write uncompressed data.tar.gz tar file to stdout.\n");
+    fprintf (fp, "   --create-time=cal_time  Use this time for archive header times\n");
+    fprintf (fp, "   --owner=NAME  package owner\n");
+    fprintf (fp, "   --group=NAME  package group\n");
+    fprintf (fp, "   --exclude=NAME  add exclude directive to the PSF\n");
+    fprintf (fp, "   --exclude-system-dirs  exclude all system directories, such as /usr, /usr/bin,...\n");
+    fprintf (fp, "   -d, --debug-level=TYPE    always use 'link'\n");
+    fprintf (fp, "   -D checkdigest  checkdigest script, applies to plain tarball translation.\n");
+    fprintf (fp, "   -x, --use-recursive-fileset Use \"file *\" instead of individual file definitions.\n");
+    fprintf (fp, "   -r, --no-leading-path   use \".\" as the leading archive path\n");
+    fprintf (fp, "   -B buffertype   mem or file  Mem is default.\n");
+    fprintf (fp, "   -H format     archive format: ustar, newc, crc, odc\n");
+    fprintf (fp, "   -p, --psf-only   Write the PSF to stdout.\n");
+    fprintf (fp, "   -o, --info-only   Write the INFO file for the rpm archive.\n");
+    fprintf (fp, "   -r, --no-leading-path.\n");
+    fprintf (fp, "   -L, --smart-leading-path  Use leading path for srpm and not rpm.\n");
     fprintf (fp, 
-		 "Howto use with swpackage:\n"
+		 "\n"
+		 "Howto use with GNU swpackage:\n"
+		 "\n"
 		 "  cat your.rpm | lxpsf --psf-form3 -H ustar | swpackage -Wsource=- -s@PSF | tar tvf -\n"
 		 "  cat your.deb | lxpsf | swpackage -Wsource=- -s@PSF | tar tvf -\n"
+		 "    # Note: you may also install the ouput of lxpsf with tar into the file\n"
+		 "    #       system, then run from that directory run swpackage normally.\n"
+		 "\n"
 		   );
 
 	fprintf (fp, "lxpsf is an implementation extension utility of the GNU swbis project\n");
@@ -118,6 +132,50 @@ void  usage (char * progname, FILE * fp) {
 	show_version(fp);
 	copyright_info(fp);
 }
+			
+static
+void
+add_system_dirs(STRAR * exclude_list)
+{
+
+	strar_add(exclude_list, "/");
+	strar_add(exclude_list, "/tmp");
+	strar_add(exclude_list, "/var");
+	strar_add(exclude_list, "/var/spool");
+	strar_add(exclude_list, "/var/log");
+	strar_add(exclude_list, "/etc");
+	strar_add(exclude_list, "/etc/init.d");
+	strar_add(exclude_list, "/usr");
+	strar_add(exclude_list, "/bin");
+	strar_add(exclude_list, "/sbin");
+	strar_add(exclude_list, "/opt");
+	strar_add(exclude_list, "/usr/sbin");
+	strar_add(exclude_list, "/usr/bin");
+	strar_add(exclude_list, "/usr/man");
+	strar_add(exclude_list, "/usr/lib");
+	strar_add(exclude_list, "/usr/info");
+	strar_add(exclude_list, "/usr/doc");
+	strar_add(exclude_list, "/usr/X11R6");
+	strar_add(exclude_list, "/usr/man/man1");
+	strar_add(exclude_list, "/usr/man/man2");
+	strar_add(exclude_list, "/usr/man/man3");
+	strar_add(exclude_list, "/usr/man/man4");
+	strar_add(exclude_list, "/usr/man/man5");
+	strar_add(exclude_list, "/usr/man/man6");
+	strar_add(exclude_list, "/usr/man/man7");
+	strar_add(exclude_list, "/usr/man/man8");
+	strar_add(exclude_list, "/usr/share");
+	strar_add(exclude_list, "/usr/share/man/man1");
+	strar_add(exclude_list, "/usr/share/man/man2");
+	strar_add(exclude_list, "/usr/share/man/man3");
+	strar_add(exclude_list, "/usr/share/man/man4");
+	strar_add(exclude_list, "/usr/share/man/man5");
+	strar_add(exclude_list, "/usr/share/man/man6");
+	strar_add(exclude_list, "/usr/share/man/man7");
+	strar_add(exclude_list, "/usr/share/man/man8");
+	strar_add(exclude_list, "/lib");
+	strar_add(exclude_list, "/libexec");
+}
 
 static
 int
@@ -467,6 +525,7 @@ main(int argc, char **argv)
 {
 	int  nfd;
 	TOPSF *topsf;
+	STRAR * exclude_list;
 	int no_leading_path = 0;
 	int ret=0;
 	int debfd;
@@ -476,17 +535,18 @@ main(int argc, char **argv)
 	int tarpipe[2];
 	char * owner;
 	char * group;
-	char  *progname;
-	char  *checkdigestname = NULL;
+	char * progname;
+	char * checkdigestname = NULL;
 	char * wopt_create_time = (char*)NULL;
-	char *path_prefix;
+	char * slack_name = NULL;
+	char * path_prefix;
 	char format[21];
 	pid_t pid;	
 	int bufferflag = UINFILE_UXFIO_BUFTYPE_DYNAMIC_MEM;
 	int use_recursive_fileset_spec = 0;
 	int single_fileset_override = 0;
 	int smart_path=0;        
-	int rpmform = 0;
+	int rpmform = 3;  /* --psf-form3 is default */
 	int do_drop_priv = 0;
 	int do_deb_control = 0;
 	int do_deb_data = 0;
@@ -495,6 +555,7 @@ main(int argc, char **argv)
 
 	progname = argv[0];
 
+	exclude_list = NULL;
 	yylval.strb = strob_open (8);
 	strcpy(swlex_filename,"none");
 	*format='\0';
@@ -530,6 +591,9 @@ main(int argc, char **argv)
                {"deb-data", 0, 0, 201},
                {"owner", 1, 0, 202},
                {"group", 1, 0, 203},
+               {"slackware-pkg-name", 1, 0, 204},
+               {"exclude", 1, 0, 205},
+               {"exclude-system-dirs", 0, 0, 206},
                {0, 0, 0, 0}
              };
 
@@ -662,6 +726,18 @@ main(int argc, char **argv)
                case 203:
 			group=strdup(optarg);
 	         	break;
+               case 204:
+			/* fprintf(stderr, "JL you're a SLACKER: %s:%s at line %d\n", __FILE__, __FUNCTION__, __LINE__); */
+			slack_name = strdup(optarg);
+	         	break;
+               case 205:
+			if (exclude_list == NULL) exclude_list = strar_open();
+			strar_add(exclude_list, optarg);
+	         	break;
+               case 206:
+			if (exclude_list == NULL) exclude_list = strar_open();
+			add_system_dirs(exclude_list);
+	         	break;
                default:
                  usage(progname, stderr);
 		 exit(1);
@@ -673,15 +749,17 @@ main(int argc, char **argv)
 	if (optind < argc) {
 		/* Open a regular file by name */
 		E_DEBUG("");
-		topsf = topsf_open(argv[optind], bufferflag);
+		topsf = topsf_open(argv[optind], bufferflag, NULL);
 	} else {
 		E_DEBUG("");
-		topsf = topsf_open("-", bufferflag);	/* stdin */
+		topsf = topsf_open("-", bufferflag, NULL);	/* stdin */
 	}
 	if (!topsf) {
 		exit(1);
 	}
 
+	topsf->exclude_listM = exclude_list;
+
 	if (owner)
 		topsf->ownerM = strdup(owner);
 	if (group)
@@ -765,11 +843,16 @@ main(int argc, char **argv)
 			E_DEBUG("");
 			if (topsf->pkgfilenameM == NULL) {
 				/* Need info from the name to translate a slackware package */
-				fprintf (stderr, "%s: slackware package, specify package file as arg()\n",
-					swlib_utilname_get());
-				fprintf (stderr, "%s: Example: swpackage --to-sw -s name-revision-arch-build.tgz\n",
-					swlib_utilname_get());
-				exit(1);
+				if (slack_name == NULL) {
+					fprintf (stderr, "%s: lxpsf: slackware package, specify package file as arg()\n",
+						swlib_utilname_get());
+					fprintf (stderr, "%s: lxpsf: Example: swpackage --to-sw -s name-revision-arch-build.tgz\n",
+						swlib_utilname_get());
+					exit(1);
+				} else {
+					/* fprintf(stderr, "JL you're a SLACKER: %s:%s at line %d\n", __FILE__, __FUNCTION__, __LINE__); */
+					topsf->pkgfilenameM = strdup(slack_name);
+				}
 			}
 			E_DEBUG("");
 			ret = write_slack(topsf);
