@@ -29,9 +29,9 @@ main(int argc, char **argv)
 	TOPSF *topsf;
 
 	if (argc <= 1) {
-		topsf = topsf_open("-", UINFILE_UXFIO_BUFTYPE_DYNAMIC_MEM);	/* stdin */
+		topsf = topsf_open("-", UINFILE_UXFIO_BUFTYPE_DYNAMIC_MEM, NULL);	/* stdin */
 	} else {
-		topsf = topsf_open(*(++argv), UINFILE_UXFIO_BUFTYPE_DYNAMIC_MEM);
+		topsf = topsf_open(*(++argv), UINFILE_UXFIO_BUFTYPE_DYNAMIC_MEM, NULL);
 	}
 	if (!topsf) {
 		exit(1);
