@@ -10,7 +10,7 @@
    *** 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -20,7 +20,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  
 */
 
 
@@ -106,11 +106,12 @@ tarui_read_in_new_ascii (TARU * taru, struct new_cpio_header * file_hdr,
 static int
 tarui_read_new_ascii_from_buf(TARU * taru, struct new_cpio_header * file_hdr,  char * ascii_header)
 {
+  unsigned long xx;
   sscanf (ascii_header,
 	  "%8lx%8lx%8lx%8lx%8lx%8lx%8lx%8lx%8lx%8lx%8lx%8lx%8lx",
 	  &file_hdr->c_ino, &file_hdr->c_mode, &file_hdr->c_uid,
 	  &file_hdr->c_gid, &file_hdr->c_nlink, &file_hdr->c_mtime,
-	  &file_hdr->c_filesize, 
+	  &xx /*file_hdr->c_filesize*/, 
 			(unsigned long*)(&file_hdr->c_dev_maj),
 			(unsigned long*)(&file_hdr->c_dev_min),
 			(unsigned long*)(&file_hdr->c_rdev_maj),
@@ -118,6 +119,7 @@ tarui_read_new_ascii_from_buf(TARU * taru, struct new_cpio_header * file_hdr,  c
 		&file_hdr->c_namesize, &file_hdr->c_chksum);
 
   /* do some checks in case the magic matched accidentally */
+  file_hdr->c_filesize  = xx;
   
   if (file_hdr->c_namesize > 6000 ) return -1;
   return 104;
