@@ -60,6 +60,11 @@
 #define THB_FL_devminor		8
 #define THB_FL_prefix		155
 
+#define XHDTYPE			'x'            /* Extended header referring to the
+                                 		  next file in the archive */
+#define XGLTYPE			'g'            /* Global extended header */
+#define GNUTYPE_LONGNAME 	'L'
+
 #define PREFIX_FIELD_SIZE 155
 #define NAME_FIELD_SIZE   100
 
@@ -403,6 +408,8 @@ int taru_get_preview_level(TARU * taru);
 
 int taru_set_tar_header_policy(TARU * taru, char * user_format, int * p_arf_format);
 
+void taru_digs_delete(FILE_DIGS *);
+
 FILE_DIGS * taru_digs_create(void);
 void taru_digs_init(FILE_DIGS *, int, int);
 void taru_digs_print(FILE_DIGS * digs, STROB * );
