@@ -375,7 +375,7 @@ int
 taruib_write_pass_files(void * vp, int ofd, int adjunct_ofd_p)
 {
 	XFORMAT * package = (XFORMAT *)vp;
-	int nullfd = open("/dev/null", O_RDWR);
+	int nullfd = swbis_devnull_open("/dev/null", O_RDWR, 0);
 	int ifd = xformat_get_ifd(package);
 	int adjunct_ofd;
 	int ret;
@@ -390,7 +390,7 @@ taruib_write_pass_files(void * vp, int ofd, int adjunct_ofd_p)
 	while ((ret = xformat_read_header(package)) > 0) {
 		retval += ret;
 		if (xformat_is_end_of_archive(package)){
-			close(nullfd);
+			swbis_devnull_close(nullfd);
 			break;
 		}
 		
@@ -557,7 +557,7 @@ taruib_write_catalog_stream(void * vp, int ofd, int version, int verbose)
 	TARU * taru = taru_create();
 
 	E_DEBUG("ENTERING");
-	nullfd = open("/dev/null", O_RDWR);
+	nullfd = swbis_devnull_open("/dev/null", O_RDWR, 0);
 	if (!swpath) return -21;
 	if (nullfd < 0) return -22;		
 	if (ifd < 0) return -32;		
@@ -770,7 +770,7 @@ taruib_write_catalog_stream(void * vp, int ofd, int version, int verbose)
 		}
 	}
 
-	close(nullfd);
+	swbis_devnull_close(nullfd);
 	E_DEBUG("");
 	strob_close(namebuf);
 	E_DEBUG("");
@@ -792,7 +792,7 @@ taruib_write_storage_stream(void * vp, int ofd, int version, int ofd2,
 						int verbose, int digest_type)
 {
 	XFORMAT * package = (XFORMAT *)vp;
-	int nullfd = open("/dev/null", O_RDWR);
+	int nullfd = swbis_devnull_open("/dev/null", O_RDWR, 0);
 	int ifd = xformat_get_ifd(package);
 	int path_ret;
 	int passfd;
@@ -840,7 +840,7 @@ taruib_write_storage_stream(void * vp, int ofd, int version, int ofd2,
 			/* fprintf(stderr, "taruib: empty payload section\n"); */
 			retval = taru_write_archive_trailer(taru, arf_ustar,
 							ofd, 512, 0, 0);
-			close(nullfd);
+			swbis_devnull_close(nullfd);
 			swpath_close(swpath);
 			strob_close(namebuf);
 			return retval;
@@ -873,7 +873,7 @@ taruib_write_storage_stream(void * vp, int ofd, int version, int ofd2,
 				if (copyret < 0) {
 					swpath_close(swpath);
 					strob_close(namebuf);
-					close(nullfd);
+					swbis_devnull_close(nullfd);
 					return copyret;
 				}
 				taruib_set_fd(nullfd);
@@ -914,7 +914,7 @@ taruib_write_storage_stream(void * vp, int ofd, int version, int ofd2,
 				if (copyret < 0) {
 					swpath_close(swpath);
 					strob_close(namebuf);
-					close(nullfd);
+					swbis_devnull_close(nullfd);
 					return copyret;
 				}
 				xformat_decrement_bytes_written(package,
@@ -990,7 +990,7 @@ taruib_write_storage_stream(void * vp, int ofd, int version, int ofd2,
 		ret = taruib_write_pass_files(vp, ofd, ofd2);
 	}
 
-	close(nullfd);
+	swbis_devnull_close(nullfd);
 	strob_close(namebuf);
 	swpath_close(swpath);
 	if (ret < 0) return -100;	
@@ -1033,7 +1033,7 @@ taruib_arfcopy(void * xpackage,
 	struct new_cpio_header * file_hdr;
         sigset_t pendmask;
 
-	nullfd = open("/dev/null", O_RDWR);
+	nullfd = swbis_devnull_open("/dev/null", O_RDWR, 0);
 	newnamebuf = strob_open(100);
 	namebuf = strob_open(100);
 	tmp = strob_open(10);
