@@ -1,10 +1,10 @@
-/* taruib.h - taru read buffer access object.
+/* taruib.h - verify archive digests
  
    Copyright (C) 2000  James H. Lowe, Jr.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -14,11 +14,12 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifndef taruib_h_0930
 #define taruib_h_0930
 
+#include "swuser_config.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -29,6 +30,9 @@
 #define TARUIB_N_SIG	 		2
 #define TARUIB_N_SHA1	   		3
 #define TARUIB_N_SIG_HDR		4
+#define TARUIB_N_SIZE	   		5
+#define TARUIB_N_SHA512	   		6
+#define TARUIB_N_MAX_INDEX   		6
 
 #define TARUIB_TEXIT_512		111
 #define TARUIB_TEXIT_1024		222
@@ -49,14 +53,14 @@ int taruib_get_nominal_reserve(void);
 int taruib_write_catalog_stream(void * XFORMATpackage, int ofd, int version, int verbose);
 int taruib_write_storage_stream(void * XFORMATpackage, int ofd, int version, int ofd2, int verbose, int digest_type);
 int taruib_write_pass_files(void * XFORMATpackage, int ofd, int adjunct_ofd_p);
-int taruib_write_signedfile_if(void * vp, int ofd, char * sigfile, int verbose, int whichsig);
+int taruib_write_signedfile_if(void * vp, int ofd, char * sigfile, int verbose, int whichsig, int logger_fd);
 void taruib_initialize_pass_thru_buffer(void);
 int taruib_arfcopy(void * xpackage, 
 		void * xswpath, 
 		int ofd, 
 		char * leadingpath, 
 		int do_preview, 
-		unsigned long int *,
+		uintmax_t *,
 		int * deadman,
 		void (*)(int));
 int taruib_arfinstall(void * swi, void * xpackage, 
@@ -64,7 +68,7 @@ int taruib_arfinstall(void * swi, void * xpackage,
 		int ofd, 
 		char * leadingpath, 
 		int do_preview, 
-		unsigned long int *,
+		uintmax_t *,
 		int * deadman,
 		void (*)(int), /*STRAR * */ void * selections);
 #endif
