@@ -319,11 +319,11 @@ main(int argc, char **argv)
 			} else {
 				int is_multi_value = 0;
 				fprintf(stdout,"enter keyword: "); get_string(keyword);
-				line = swheader_get_attribute_in_object(swheader,  keyword, object_keyword, &is_multi_value);
+				line = swheader_get_attribute_in_current_object(swheader,  keyword, object_keyword, &is_multi_value);
 				fprintf(stdout, "is_multi_value = [%d]\n", is_multi_value);
 				while (line) {
 					swheaderline_write_debug(line, STDOUT_FILENO);
-					line = swheader_get_attribute_in_object(swheader, keyword, object_keyword, &is_multi_value);
+					line = swheader_get_attribute_in_current_object(swheader, keyword, object_keyword, &is_multi_value);
 				}
 			}
 		break;
