@@ -40,6 +40,7 @@
 #include "swfork.h"
 #include "u_ar.h"
 #include "ls_list.h"
+#include "swgpg.h"
 
 #include "debug_config.h"
 #define UINFILENEEDDEBUG 1
@@ -410,7 +411,6 @@ uinfile_i_open(char *filename, int oflag, mode_t mode, UINFORMAT ** uinformat,
 	char lzmamagic[] = UINFILE_MAGIC_lzma;
 	char xzmamagic[] = UINFILE_MAGIC_xz;
 	char debmagic[] = UINFILE_MAGIC_deb;
-	char slackmagic[] = UINFILE_MAGIC_slack;
 	char *zcat_command = (char *) (NULL);
 	pid_t a_pid;
 	intmax_t pump_amount = -1;
@@ -1281,7 +1281,7 @@ LABEL_REREAD:
 	} else if ((*uinformat)->ztypeM == UINFILE_COMPRESSED_GPG) {
 		UINFILE_E_DEBUG("in gpg code");
 		unzip[0] = shcmd_open();
-		shcmd_add_arg(unzip[0], "gpg");
+		shcmd_add_arg(unzip[0], SWGPG_GPG_BIN);
 		shcmd_add_arg(unzip[0], "--decrypt");
 		shcmd_add_arg(unzip[0], "--use-agent");
 		shcmd_add_arg(unzip[0], "--no-verbose");
