@@ -6,7 +6,7 @@
 #include <string>
 
 #include <typeinfo>
-#include "stream_config.h"
+#include "xstream_config.h"
 #include "swparser.h"
 #include "swindex.h"
 #include "swpackagefile.h"
