@@ -6,7 +6,7 @@ check_for_gnu_tar()
 		2.[0-9].*)
 			echo 1>/dev/null
 		;;
-		1.14|1.14.*|1.15*|1.13.17|1.13.25|1.1[6-9]|1.1[6-9].*)
+		1.14|1.14.*|1.15*|1.13.17|1.13.25|1.1[6-9]|1.1[6-9].*|1.[2-9][0-9]|1.[2-9][0-9]*)
 			echo 1>/dev/null
 		;;
 		*)
@@ -21,7 +21,7 @@ check_for_gnu_tar()
 make_format_option()
 {
 	case "$gnu_tar_version" in 
-		1.14|1.14.*|1.15*|1.13.17|1.13.25|1.1[6-9]|1.1[6-9].*)
+		1.14|1.14.*|1.15*|1.13.17|1.13.25|1.1[6-9]|1.1[6-9].*|1.[2-9][0-9]|1.[2-9][0-9]*)
 			case "$opt_format" in
 				gnu)
 					GNUTAR_FORMAT_OPTIONS="-b1 --format=gnu"
